@@ -6,7 +6,7 @@ use 5.008001;
 use Carp qw( croak );
 
 # ABSTRACT: Write Perl bindings to non-Perl libraries with FFI. No XS required.
-our $VERSION = '0.42'; # VERSION
+our $VERSION = '0.43'; # VERSION
 
 # Platypus Man,
 # Platypus Man,
@@ -530,7 +530,7 @@ sub _have_pm
 
 package FFI::Platypus::Function;
 
-our $VERSION = '0.42'; # VERSION
+our $VERSION = '0.43'; # VERSION
 
 use overload '&{}' => sub {
   my $ffi = shift;
@@ -551,7 +551,7 @@ use overload '&{}' => sub {
   sub { $self->{code}->(@_) };
 };
 
-our $VERSION = '0.42'; # VERSION
+our $VERSION = '0.43'; # VERSION
 
 sub new
 {
@@ -580,13 +580,13 @@ sub get_data
 
 package FFI::Platypus::ClosureData;
 
-our $VERSION = '0.42'; # VERSION
+our $VERSION = '0.43'; # VERSION
 
 package FFI::Platypus::Type;
 
 use Carp qw( croak );
 
-our $VERSION = '0.42'; # VERSION
+our $VERSION = '0.43'; # VERSION
 
 sub new
 {
@@ -680,7 +680,7 @@ FFI::Platypus - Write Perl bindings to non-Perl libraries with FFI. No XS requir
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =head1 SYNOPSIS
 
@@ -772,14 +772,10 @@ support and development (for contributors) information.  If you are new
 to Platypus or FFI, you may want to skip down to the 
 L<EXAMPLES|/EXAMPLES> to get a taste of what you can do with Platypus.
 
-Platypus also provides an declarative interface you may want to use 
-instead of the object oriented interface called 
-L<FFI::Platypus::Declare>.
-
 Platypus has extensive documentation of types at L<FFI::Platypus::Type> 
 and its custom types API at L<FFI::Platypus::API>.
 
-=for stopwords ÃMQ
+=for stopwords ØMQ
 
 =head1 CONSTRUCTORS
 
@@ -1163,19 +1159,20 @@ value from the L</abis> method above.
 
 =head1 EXAMPLES
 
-Here are some examples.  Some of them use the L<FFI::Platypus::Declare> 
-interface, but the principles apply to the OO interface.  These examples 
+Here are some examples.  These examples 
 are provided in full with the Platypus distribution in the "examples" 
 directory.  There are also some more examples in L<FFI::Platypus::Type> 
 that are related to types.
 
 =head2 Integer conversions
 
- use FFI::Platypus::Declare qw( int string );
+ use FFI::Platypus;
  
- lib undef;
- attach puts => [string] => int;
- attach atoi => [string] => int;
+ my $ffi = FFI::Platypus->new;
+ $ffi->lib(undef);
+ 
+ $ffi->attach(puts => ['string'] => 'int');
+ $ffi->attach(atoi => ['string'] => 'int');
  
  puts(atoi('56'));
 
@@ -1188,20 +1185,21 @@ includes the standard c library.
 =head2 libnotify
 
  use FFI::CheckLib;
- use FFI::Platypus::Declare qw( void string opaque );
+ use FFI::Platypus;
  
  # NOTE: I ported this from the like named eg/notify.pl that came with FFI::Raw
  # and it seems to work most of the time, but also seems to SIGSEGV sometimes.
  # I saw the same behavior in the FFI::Raw version, and am not really familiar
  # with the libnotify API to say what is the cause.  Patches welcome to fix it.
  
- lib find_lib_or_exit lib => 'notify';
+ my $ffi = FFI::Platypus->new;
+ $ffi->lib(find_lib_or_exit lib => 'notify');
  
- attach notify_init   => [string] => void;
- attach notify_uninit => []       => void;
- attach [notify_notification_new    => 'notify_new']    => [string,string,string]           => opaque;
- attach [notify_notification_update => 'notify_update'] => [opaque, string, string, string] => void;
- attach [notify_notification_show   => 'notify_show']   => [opaque, opaque]                 => void;
+ $ffi->attach(notify_init   => ['string'] => 'void');
+ $ffi->attach(notify_uninit => []       => 'void');
+ $ffi->attach([notify_notification_new    => 'notify_new']    => ['string', 'string', 'string']           => 'opaque');
+ $ffi->attach([notify_notification_update => 'notify_update'] => ['opaque', 'string', 'string', 'string'] => 'void');
+ $ffi->attach([notify_notification_show   => 'notify_show']   => ['opaque', 'opaque']                     => 'void');
  
  notify_init('FFI::Platypus');
  my $n = notify_new('','','');
@@ -1243,14 +1241,15 @@ We are really calling the C function C<notify_notification_new>.
 
 =head2 Allocating and freeing memory
 
- use FFI::Platypus::Declare;
+ use FFI::Platypus;
  use FFI::Platypus::Memory qw( malloc free memcpy );
  
+ my $ffi = FFI::Platypus->new;
  my $buffer = malloc 12;
  
- memcpy $buffer, cast('string' => 'opaque', "hello there"), length "hello there\0";
+ memcpy $buffer, $ffi->cast('string' => 'opaque', "hello there"), length "hello there\0";
  
- print cast('opaque' => 'string', $buffer), "\n";
+ print $ffi->cast('opaque' => 'string', $buffer), "\n";
  
  free $buffer;
 
@@ -1314,16 +1313,16 @@ structured data records).
 =head2 libuuid
 
  use FFI::CheckLib;
- use FFI::Platypus::Declare
-   'void',
-   [ 'string(37)' => 'uuid_string' ],
-   [ 'record(16)' => 'uuid_t' ];
+ use FFI::Platypus;
  use FFI::Platypus::Memory qw( malloc free );
  
- lib find_lib_or_exit lib => 'uuid';
+ my $ffi = FFI::Platypus->new;
+ $ffi->lib(find_lib_or_exit lib => 'uuid');
+ $ffi->type('string(37)' => 'uuid_string');
+ $ffi->type('record(16)' => 'uuid_t');
  
- attach uuid_generate => [uuid_t] => void;
- attach uuid_unparse  => [uuid_t,uuid_string] => void;
+ $ffi->attach(uuid_generate => ['uuid_t'] => 'void');
+ $ffi->attach(uuid_unparse  => ['uuid_t','uuid_string'] => 'void');
  
  my $uuid = "\0" x 16;  # uuid_t
  uuid_generate($uuid);
@@ -1345,11 +1344,13 @@ this case it is simply 16 bytes).  We also know that the strings
 
 =head2 puts and getpid
 
- use FFI::Platypus::Declare qw( string int );
+ use FFI::Platypus;
  
- lib undef;
- attach puts => [string] => int;
- attach getpid => [] => int;
+ my $ffi = FFI::Platypus->new;
+ $ffi->lib(undef);
+ 
+ $ffi->attach(puts => ['string'] => 'int');
+ $ffi->attach(getpid => [] => 'int');
  
  puts(getpid());
 
@@ -1358,20 +1359,21 @@ C<getpid> is available on Unix type platforms.
 
 =head2 Math library
 
- use FFI::Platypus::Declare qw( string int double );
+ use FFI::Platypus;
  use FFI::CheckLib;
  
- lib undef;
- attach puts => [string] => int;
- attach fdim => [double,double] => double;
+ my $ffi = FFI::Platypus->new;
+ $ffi->lib(undef);
+ $ffi->attach(puts => ['string'] => 'int');
+ $ffi->attach(fdim => ['double','double'] => 'double');
  
  puts(fdim(7.0, 2.0));
  
- attach cos => [double] => double;
+ $ffi->attach(cos => ['double'] => 'double');
  
  puts(cos(2.0));
  
- attach fmax => [double, double] => double;
+ $ffi->attach(fmax => ['double', 'double'] => 'double');
  
  puts(fmax(2.0,3.0));
 
@@ -1384,15 +1386,16 @@ use C<undef> as the library to find them.
 
 =head2 Strings
 
- use FFI::Platypus::Declare qw( int string );
+ use FFI::Platypus;
  
- lib undef;
- attach puts => [string] => int;
- attach strlen => [string] => int;
+ my $ffi = FFI::Platypus->new;
+ $ffi->lib(undef);
+ $ffi->attach(puts => ['string'] => 'int');
+ $ffi->attach(strlen => ['string'] => 'int');
  
  puts(strlen('somestring'));
  
- attach strstr => [string,string] => string;
+ $ffi->attach(strstr => ['string','string'] => 'string');
  
  puts(strstr('somestring', 'string'));
  
@@ -1400,7 +1403,7 @@ use C<undef> as the library to find them.
  
  puts(puts("lol"));
  
- attach strerror => [int] => string;
+ $ffi->attach(strerror => ['int'] => 'string');
  
  puts(strerror(2));
 
@@ -1506,7 +1509,7 @@ just-in-time (JIT) compilation service for FFI.
    print "recv_message = $recv_message\n";
  };
 
-B<Discussion>: ÃMQ is a high-performance asynchronous messaging library.  
+B<Discussion>: ØMQ is a high-performance asynchronous messaging library.  
 There are a few things to note here.
 
 Firstly, sometimes there may be multiple versions of a library in the 
@@ -1531,7 +1534,7 @@ the same, it is useful form of documentation that helps describe the
 functionality of the interface.
 
 Finally we attach the necessary functions, send and receive a message. 
-If you are interested, there is a fully fleshed out ÃMQ Perl interface 
+If you are interested, there is a fully fleshed out ØMQ Perl interface 
 implemented using FFI called L<ZMQ::FFI>.
 
 =head2 libarchive
@@ -2014,7 +2017,7 @@ bit Perl as well.
  
  
  DEBUG_FAKE32:
-   + making Math::Int64 a prerequsite (not normally done on 64 bit Perls)
+   + making Math::Int64 a prerequisite (not normally done on 64 bit Perls)
    + using Math::Int64's C API to manipulate 64 bit values (not normally done on 64 bit Perls)
  
  Created MYMETA.yml and MYMETA.json
@@ -2096,9 +2099,9 @@ C<PERL5LIB> path when you build Platypus.  For example:
 
 =over 4
 
-=item L<FFI::Platypus::Declare>
+=item L<NativeCall>
 
-Declarative interface to Platypus.
+Promising interface to Platypus inspired by Perl 6.
 
 =item L<FFI::Platypus::Type>
 
@@ -2249,6 +2252,8 @@ Fitz Elliott (felliott)
 
 Vickenty Fesunov (vyf)
 
+Gregor Herrmann (gregoa)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Graham Ollis.
