@@ -7,7 +7,7 @@ use Scalar::Util qw( readonly );
 use Config ();
 
 # ABSTRACT: Convert a pointer to a string and back
-our $VERSION = '0.42'; # VERSION
+our $VERSION = '0.43'; # VERSION
 
 
 use constant _incantation =>
@@ -76,7 +76,7 @@ FFI::Platypus::Type::StringPointer - Convert a pointer to a string and back
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =head1 SYNOPSIS
 
@@ -95,12 +95,13 @@ In your C code:
 
 In your Platypus::FFI code:
 
- use FFI::Platypus::Declare
-   'void',
-   [ '::StringPointer' => 'string_pointer' ];
+ use FFI::Platypus;
  
- attach string_pointer_argument => [string_pointer] => void;
- attach string_pointer_return   => [] => string_pointer;
+ my $ffi = FFI::Platypus->new;
+ $ffi->load_custom_type('::StringPointer' => 'string_pointer');
+ 
+ $ffi->attach(string_pointer_argument => ['string_pointer'] => 'void');
+ $ffi->attach(string_pointer_return   => [] => 'string_pointer');
  
  my $string = "foo";
  
@@ -123,10 +124,6 @@ strings.
 
 Main Platypus documentation.
 
-=item L<FFI::Platypus::Declare>
-
-Declarative interface for Platypus.
-
 =item L<FFI::Platypus::Type>
 
 Platypus types documentation.
@@ -151,6 +148,8 @@ Fitz Elliott (felliott)
 
 Vickenty Fesunov (vyf)
 
+Gregor Herrmann (gregoa)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Graham Ollis.
