@@ -12,7 +12,7 @@ use Config;
 use base qw( Module::Build );
 
 # ABSTRACT: Build Perl extensions in C with FFI
-our $VERSION = '0.42'; # VERSION
+our $VERSION = '0.43'; # VERSION
 
 
 __PACKAGE__->add_property( ffi_libtest_dir =>
@@ -303,7 +303,7 @@ Module::Build::FFI - Build Perl extensions in C with FFI
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =head1 SYNOPSIS
 
@@ -334,16 +334,7 @@ Put your .c and .h files in C<ffi> (C<ffi/example.c>):
    printf("hello world\n");
  }
 
-Attach it to Perl in your main module (C<lib/Foo/Bar.pm>) using
-the declarative interface:
-
- package Foo::Bar;
- 
- use FFI::Platypus::Declare qw( void );
- 
- attach hello_world => [] => void;
-
-or use the OO interface:
+Attach it to Perl in your main module (C<lib/Foo/Bar.pm>):
 
  package Foo::Bar;
  
@@ -388,10 +379,10 @@ can use to test your FFI module with.  You can use FFI::CheckLib to
 find the library from your test:
 
  use Test::More;
- use FFI::Platypus::Declare;
+ use FFI::Platypus;
  use FFI::CheckLib;
  
- lib find_lib lib => 'test', libpath => 'libtest';
+ FFI::Platypus->new->lib(find_lib lib => 'test', libpath => 'libtest');
 
 [version 0.18]
 
@@ -530,6 +521,8 @@ Fitz Elliott (felliott)
 
 Vickenty Fesunov (vyf)
 
+Gregor Herrmann (gregoa)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Graham Ollis.
